import { Command, Application as Craft } from '@supercharge/console';
import { Application, BootstrapperCtor, ConsoleKernel as ConsoleKernelContract } from '@supercharge/contracts';
export declare class ConsoleKernel implements ConsoleKernelContract {
    /**
     * Stores the internal configuration.
     */
    private readonly meta;
    /**
     * Create a new console kernel instance.
     */
    constructor(app: Application);
    /**
     * Create a new console kernel instance for the given `app`.
     */
    static for(app: Application): ConsoleKernel;
    /**
     * Returns the application instance.
     */
    app(): Application;
    /**
     * Returns the list of application bootstrappers.
     */
    protected bootstrappers(): BootstrapperCtor[];
    /**
     * Handle an incoming console command for the given `input`.
     */
    run(input?: string[]): Promise<any>;
    /**
     * Prepare the console application by running the configured bootstrappers.
     * This method doesn’t register configured commands in the application.
     * It prepares the console application which is useful for testing.
     */
    prepare(): Promise<this>;
    /**
     * Bootstrap the console application for Craft commands.
     */
    bootstrap(): Promise<void>;
    /**
     * Register the console commands to the application.
     */
    commands(): Promise<void>;
    /**
     * Register all of the commands in the given `directories`.
     */
    loadCommandsFromPaths(...paths: string[]): Promise<void>;
    /**
     * Requires the given file from disk.
     */
    resolveCommandFrom(commandFile: string): Promise<Command>;
    /**
     * Returns a Craft console application instance.
     */
    craft(): Craft;
}
