import { HttpError as BaseHttpError } from '@supercharge/errors';
export class HttpError extends BaseHttpError {
    /**
     * Create a new HTTP error instance.
     */
    constructor(message, cause) {
        super(message, { cause });
        this.withStatus(500);
    }
    /**
     * Returns a new HTTP error instance wrapping the given `error`.
     */
    static wrap(error) {
        const err = new this(error.message, error).withStatus(this.retrieveStatusFrom(error));
        if (error.stack) {
            err.withStack(error.stack);
        }
        return err;
    }
    /**
     * Retrieves an available status code from the error instance.
     * Falls back to HTTP status 500 if no status code is found.
     */
    static retrieveStatusFrom(error) {
        return error.status || error.statusCode || 500;
    }
    /**
     * Report the given `error` on the related HTTP `ctx`. Return a `falsy`
     * value if you don’t want the Supercharge error handler to run the
     * registered reporters and logging for the given error instance.
     */
    report(_error, _ctx) {
        //
    }
    /**
     * Render the given `error` on the related HTTP `ctx`. Return a `falsy`
     * value if you don’t want the Supercharge error handler to render
     *  the error instance into an HTTP response, like view or JSON.
     */
    render(_error, _ctx) {
        //
    }
}
