import { Application, BootstrapperCtor, HttpKernel as HttpKernelContract, HttpServer, HttpServerHandler, MiddlewareCtor } from '@supercharge/contracts';
type Callback = () => unknown | Promise<unknown>;
export declare class HttpKernel implements HttpKernelContract {
    /**
     * Stores the HTTP kernel’s meta data.
     */
    private readonly meta;
    /**
     * Create a new HTTP kernel instance.
     */
    constructor(app: Application);
    /**
     * Creates a new HTTP kernel instance for the given `app`.
     */
    static for(app: Application): HttpKernel;
    /**
     * Returns the app instance.
     */
    app(): Application;
    /**
     * Register the HTTP base bindings into the container.
     */
    private registerHttpContainerBindings;
    /**
     * Determine whether the HTTP kernel is already boostrapped.
     */
    isBootstrapped(): boolean;
    /**
     * Determine whether the HTTP kernel is not boostrapped yet.
     */
    isNotBootstrapped(): boolean;
    /**
     * Mark this HTTP kernel as bootstrapped.
     */
    markAsBootstrapped(): this;
    /**
     * Returns the HTTP server instance.
     */
    server(): HttpServer;
    /**
     * Register the booting or booted callbacks. For example, you may use a `booted`
     * callback to send a "ready" signal to PM2 (or any other process manager)
     * informing that your HTTP server is ready to accept incoming requests.
     */
    register(): void;
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     */
    middleware(): MiddlewareCtor[];
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     */
    routeMiddleware(): {
        [key: string]: MiddlewareCtor;
    };
    /**
     * Register a booted callback that runs after the HTTP server started.
     */
    booted(callback: Callback): this;
    /**
     * Returns the booted callbacks.
     */
    bootedCallbacks(): Callback[];
    /**
     * Returns a request handler callback compatible with Node.js’ native HTTP server. This method
     * bootstraps the HTTP server instance by registering routes and middleware before returning
     * it. This request handler callback is useful during testing when sending requests into
     * the HTTP server instance with a community package, like Supertest from visionmedia.
     */
    serverCallback(): Promise<HttpServerHandler>;
    /**
     * Start the HTTP instance listening for incoming requests.
     */
    startServer(): Promise<this>;
    /**
     * Start the HTTP server to listen on a local port.
     */
    protected listen(): Promise<void>;
    /**
     * Stop the HTTP instance.
     */
    stopServer(): Promise<this>;
    /**
     * Prepare the application by running the configured bootstrappers. This
     * method doesn’t register routes or middleware to the underlying HTTP
     * server. It prepares the application which is useful for testing.
     */
    prepare(): Promise<this>;
    /**
     * Bootstrap the HTTP kernel by loading environment variables and all files
     * within the `config` directory, register and boot all the given service
     * providers, and ultimately register the HTTP middleware and routes.
     */
    bootstrap(): Promise<void>;
    /**
     * Returns the list of application bootstrappers.
     */
    bootstrappers(): BootstrapperCtor[];
    /**
     * Register the configured middleware stacks to the HTTP server.
     */
    registerMiddleware(): void;
    /**
     * Register the application middleware stack to the HTTP server.
     */
    registerAppMiddleware(): void;
    /**
     * Sync the available middleware to the router.
     */
    registerRouteLevelMiddleware(): void;
    /**
     * Run the configured `booted` callbacks.
     */
    protected runBootedCallbacks(): Promise<void>;
    /**
     * Call the given kernal `callbacks`.
     */
    protected runCallbacks(callbacks: Callback[]): Promise<void>;
}
export {};
