import { tap } from '@supercharge/goodies';
import { ServiceProvider } from '@supercharge/support';
export class RouteServiceProvider extends ServiceProvider {
    /**
     * Stores the callback functions that load route files.
     */
    loadRoutesCallbacks = [];
    /**
     * Register application services to the container.
     */
    register() {
        this.booted(async () => {
            await this.runRouteLoadingCallbacks();
        });
    }
    /**
     * Run the registered route-loading callbacks.
     */
    async runRouteLoadingCallbacks() {
        for (const callback of this.loadRoutesCallbacks) {
            await callback();
        }
    }
    /**
     * Load the routes file from the given `path`.
     */
    loadRoutesFrom(path) {
        return this.loadRoutesUsing(async () => {
            await import(`${path}?imported=${Date.now()}`);
        });
    }
    /**
     * Register a callback that will be used to load the application’s routes.
     */
    loadRoutesUsing(callback) {
        return tap(this, () => {
            this.loadRoutesCallbacks.push(callback);
        });
    }
}
