/// <reference types="node" resolution-mode="require"/>
import { Application } from '@supercharge/contracts';
export type OnShutdownCallback = () => Promise<void> | void;
export declare class ShutdownSignalListener {
    /**
     * Stores the application instance.
     */
    protected readonly app: Application;
    /**
     * Stores the shutdown signals to listen on.
     */
    protected shutdownSignals: NodeJS.Signals[];
    /**
     * Stores the shutdown callback.
     */
    protected onShutdownCallbacks: OnShutdownCallback[];
    /**
     * Invoke callback and exit process
     */
    protected kill: (signal: NodeJS.Signals) => Promise<never>;
    /**
     * Create a new instance.
     */
    constructor(app: Application);
    /**
     * Assign the given shutdown `callback` that runs when receiving a shutdown signal.
     */
    onShutdown(callback: OnShutdownCallback): this;
    /**
     * Close on SIGINT AND SIGTERM SIGNALS
     */
    listen(...signals: NodeJS.Signals[] | NodeJS.Signals[][]): void;
    /**
     * Register the shutdown handler to run for the given `signals`.
     */
    private runShutdownCallbackOn;
    /**
     * Remove the event listeners for shutdown signals and
     * reset the shutdown callback to a no-op function.
     */
    cleanup(): this;
}
